@@ -318,8 +318,7 @@ class ChangePointModel(Model):
         if interval is None:
             interval = self.min_interval
         min_available_interval_num = self.interval_tiers[self.min_interval]
-        print(min_available_interval_num)
-        desired_interval_num = self.interval_tiers["Hourly"]
+        desired_interval_num = self.interval_tiers[self.min_interval]
 
         if min_available_interval_num > desired_interval_num:
             self.df = self.group_interval(time_interval=interval,
