@@ -52,14 +52,13 @@ class NMEC:
         pass
 
     def model_with_changepoint(self, df: pd, cp_type="SLR"):
-        my_model = ChangePointModel(df)
+        my_model = ChangePointModel(df, model_name = cp_type)
         
         if cp_type.upper() in ["3PH", "3PC"]:
             df = my_model.df
             train_estimate = my_model.train(df.dropna().copy())
 
-            return {"occupied model": my_model.p, "unoccupied model": None,
-                    "data": train_estimate
+            return {"data": train_estimate
                     # 'metrics': my_model.metrics(train_estimate)
                     }
 
@@ -88,7 +87,7 @@ class NMEC:
                     'No Training Estimate, check if Type is SLR, 2P, 3PH, or 3PC')
   
 
-    def example(self, model_type="SLR"):
+    def example(self, model_type="3PH"):
         print("modeling with type", model_type)
 
         df = pd.read_csv(
