@@ -104,10 +104,10 @@ class TOWTModel(Model):
             self.knot_temps = knot_temps
 
         if interval is None:
-            interval = self.min_interval
+            interval = str(self.min_interval)
         
         min_available_interval_num = self.interval_tiers[self.min_interval]
-        desired_interval_num = self.interval_tiers[interval]
+        desired_interval_num = self.interval_tiers[str(interval)]
 
         if min_available_interval_num > desired_interval_num:
             self.df = self.group_interval(time_interval=interval,
@@ -168,7 +168,7 @@ class TOWTModel(Model):
             unocc_model = LinearRegression().fit(unocc_x_train, unocc_y_train)
             self.unocc_model = unocc_model
 
-        '''
+        
         occ_model, occ_train = model_and_predict(train=train, occupied=True)
         # Unoccupied model
         unocc_model = None
@@ -191,8 +191,8 @@ class TOWTModel(Model):
                   'knot_temps': (knot_temps, used_knot_temps),
                   'metrics': metrics}
         return(output)
-        '''
-        return(main)
+        
+        #return(main)
 
     def predict(self, df, occ_model=None, unocc_model=None):
         """
